==> json-api-merge-1.1.2.tgz: package/es/index.js <==
import { curry, has, keys, pipe, isNil, propOr, reduce, assoc, path as rpath, concat, insert, assocPath } from 'ramda';
import { mapIndexed, reduceIndexed, ensureArray, isArray } from 'ramda-adjunct'; // Type definitions:
//     Resource = Object
//     ResourceRel = {type: String, id: Number}
//     ResourceKey = String
//     Relationships = Object
//     Included = [Resource]
//     IncludedCache = {k: ResourceKey, v: Resource}
//     RelPath = {path: String, key: ResourceKey}
// getRelationships :: Resource -> Relationships

var getRelationships = pipe(propOr({}, ['relationships']), keys); // resourceKey :: ResourceRel -> ResourceKey

var resourceKey = function resourceKey(_ref) {
  var type = _ref.type,
      id = _ref.id;
  return "".concat(type, "-").concat(id);
}; // createIncludedCache :: Included -> IncludedCache


var createIncludedCache = reduce(function (acc, resource) {
  return assoc(resourceKey(resource), resource, acc);
}, {}); // relToPath :: (String, ResourceRel) -> RelPath

var relToPath = function relToPath(relationship, _ref2) {
  var type = _ref2.type,
      id = _ref2.id;
  return {
    path: ['relationships', relationship, 'data'],
    key: resourceKey({
      type: type,
      id: id
    })
  };
}; // relToPaths :: (String, [ResourceRel]) -> [RelPath]


var relToPaths = function relToPaths(relationship, resources) {
  return mapIndexed(function (resource, index) {
    return {
      path: ['relationships', relationship, 'data', index],
      key: resourceKey(resource)
    };
  }, resources);
}; // getRelPaths :: Resource -> [RelPath]


var getRelPaths = function getRelPaths(resource) {
  var relationships = getRelationships(resource);
  return reduce(function (acc, relationship) {
    var relData = resource.relationships[relationship].data;
    var paths = ensureArray(isArray(relData) ? relToPaths(relationship, relData) : relToPath(relationship, relData));
    return concat(acc, paths);
  }, [], relationships);
}; // jsonApiMergeSingle :: (Included, Resource) -> Resource


var jsonApiMergeSingle = function jsonApiMergeSingle(includedCache, resource) {
  var relPaths = getRelPaths(resource);
  return reduce(function (acc, _ref3) {
    var key = _ref3.key,
        path = _ref3.path;
    var includedResource = has(key, includedCache) ? includedCache[key] : rpath(path, resource);
    return assocPath(path, includedResource, acc);
  }, resource, relPaths);
}; // jsonApiMergeMulti :: (IncludedCache, [Resource]) -> [Resource]


var jsonApiMergeMulti = function jsonApiMergeMulti(includedCache, resources) {
  return reduceIndexed(function (acc, datum, index) {
    var mergedDatum = jsonApiMergeSingle(includedCache, datum);
    return insert(index, mergedDatum, acc);
  }, [], resources);
}; // jsonApiMerge :: (Included, Resource) -> Resource
// jsonApiMerge :: (Included, [Resource]) -> [Resource]


var jsonApiMerge = curry(function (included, resource) {
  if (isNil(included)) return resource;
  var includedCache = createIncludedCache(included);
  return isArray(resource) ? jsonApiMergeMulti(includedCache, resource) : jsonApiMergeSingle(includedCache, resource);
});
export default jsonApiMerge;

==> json-api-merge-1.1.4.tgz: package/es/index.js <==
import { curry, has, keys, pipe, isNil, propOr, reduce, assoc, path as rpath, concat, insert, assocPath, pickBy } from 'ramda';
import { mapIndexed, reduceIndexed, ensureArray, isArray } from 'ramda-adjunct';

// Type definitions:
//     Resource = Object
//     ResourceRel = {type: String, id: Number}
//     ResourceKey = String
//     Relationships = Object
//     Included = [Resource]
//     IncludedCache = {k: ResourceKey, v: Resource}
//     RelPath = {path: String, key: ResourceKey}

// getRelationships :: Resource -> Relationships
var getRelationships = pipe(propOr({}, ['relationships']), pickBy(has('data')), keys);

// resourceKey :: ResourceRel -> ResourceKey
var resourceKey = function resourceKey(_ref) {
  var type = _ref.type,
    id = _ref.id;
  return "".concat(type, "-").concat(id);
};

// createIncludedCache :: Included -> IncludedCache
var createIncludedCache = reduce(function (acc, resource) {
  return assoc(resourceKey(resource), resource, acc);
}, {});

// relToPath :: (String, ResourceRel) -> RelPath
var relToPath = function relToPath(relationship, _ref2) {
  var type = _ref2.type,
    id = _ref2.id;
  return {
    path: ['relationships', relationship, 'data'],
    key: resourceKey({
      type: type,
      id: id
    })
  };
};

// relToPaths :: (String, [ResourceRel]) -> [RelPath]
var relToPaths = function relToPaths(relationship, resources) {
  return mapIndexed(function (resource, index) {
    return {
      path: ['relationships', relationship, 'data', index],
      key: resourceKey(resource)
    };
  }, resources);
};

// getRelPaths :: Resource -> [RelPath]
var getRelPaths = function getRelPaths(resource) {
  var relationships = getRelationships(resource);
  return reduce(function (acc, relationship) {
    var relData = resource.relationships[relationship].data;
    var paths = ensureArray(isArray(relData) ? relToPaths(relationship, relData) : relToPath(relationship, relData));
    return concat(acc, paths);
  }, [], relationships);
};

// jsonApiMergeSingle :: (Included, Resource) -> Resource
var jsonApiMergeSingle = function jsonApiMergeSingle(includedCache, resource) {
  var relPaths = getRelPaths(resource);
  return reduce(function (acc, _ref3) {
    var key = _ref3.key,
      path = _ref3.path;
    var includedResource = has(key, includedCache) ? includedCache[key] : rpath(path, resource);
    return assocPath(path, includedResource, acc);
  }, resource, relPaths);
};

// jsonApiMergeMulti :: (IncludedCache, [Resource]) -> [Resource]
var jsonApiMergeMulti = function jsonApiMergeMulti(includedCache, resources) {
  return reduceIndexed(function (acc, datum, index) {
    var mergedDatum = jsonApiMergeSingle(includedCache, datum);
    return insert(index, mergedDatum, acc);
  }, [], resources);
};

// jsonApiMerge :: (Included, Resource) -> Resource
// jsonApiMerge :: (Included, [Resource]) -> [Resource]
var jsonApiMerge = curry(function (included, resource) {
  if (isNil(included)) return resource;
  var includedCache = createIncludedCache(included);
  return isArray(resource) ? jsonApiMergeMulti(includedCache, resource) : jsonApiMergeSingle(includedCache, resource);
});
export default jsonApiMerge;
